@@ -1,6 +1,8 @@
 """
 Python API for Notice data.
 """
+import datetime
+
 from django.conf import settings
 from rest_framework.reverse import reverse
 
@@ -37,7 +39,18 @@ def can_dismiss(user, notice):
     except AcknowledgedNotice.DoesNotExist:
         return True
 
+    snooze_count_limit_exceeded = False
     snooze_limit = settings.FEATURES.get("NOTICES_SNOOZE_COUNT_LIMIT")
-    if snooze_limit is not None and acknowledged_notice.snooze_count < snooze_limit:
-        return True
-    return False
+    if snooze_limit is not None and acknowledged_notice.snooze_count >= snooze_limit:
+        snooze_count_limit_exceeded = True
+
+    max_snooze_days_exceeded = False
+    max_snooze_days = settings.FEATURES.get("NOTICES_MAX_SNOOZE_DAYS")
+    if max_snooze_days is not None:
+        current_time = datetime.datetime.now(datetime.timezone.utc)
+        max_time_before_now = current_time - datetime.timedelta(days=max_snooze_days)
+        max_snooze_days_exceeded = acknowledged_notice.created < max_time_before_now
+
+    if any([snooze_count_limit_exceeded, max_snooze_days_exceeded]):
+        return False
+    return True
